==> plee-the-bear_0.5.1.orig.tar.gz: plee-the-bear-0.5.1/plee-the-bear/src/ptb/player_state/state_maintain.hpp <==
/*
  Plee the Bear

  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file state_maintain.hpp
 * \brief The class describing the state where the player prepare
 * to throw a stone.
 * \author Sebastien Angibaud
 */
#ifndef __PTB_STATE_MAINTAIN_HPP__
#define __PTB_STATE_MAINTAIN_HPP__

#include "ptb/player_state/state_player.hpp"

namespace ptb
{
  /**
   * \brief The class describing a state where the player start to throw a
   *        stone.
   * \author Sebastien Angibaud
   */
  class state_maintain : public state_player
  {
  public:
    /** \brief The type of the parent class. */
    typedef state_player super;

  public:
    state_maintain(player* player);

    virtual std::string get_name() const;
    virtual void start();

    virtual void do_start_throw();
    virtual void do_stop_throw();
    virtual void do_look_upward();
    virtual void do_continue_look_upward();
    virtual void do_crouch();
    virtual void do_continue_crouch();
  }; // class state_maintain
} // namespace ptb

#endif // __PTB_STATE_MAINTAIN_HPP__

==> plee-the-bear_0.6.0.orig.tar.gz: plee-the-bear-0.6.0/plee-the-bear/src/ptb/player_state/state_maintain.hpp <==
/*
  Plee the Bear

  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file state_maintain.hpp
 * \brief The class describing the state where the player prepare
 * to throw a stone.
 * \author Sebastien Angibaud
 */
#ifndef __PTB_STATE_MAINTAIN_HPP__
#define __PTB_STATE_MAINTAIN_HPP__

#include "ptb/player_state/state_player.hpp"

namespace ptb
{
  /**
   * \brief The class describing a state where the player start to throw a
   *        stone.
   * \author Sebastien Angibaud
   */
  class state_maintain : public state_player
  {
  public:
    /** \brief The type of the parent class. */
    typedef state_player super;

  public:
    state_maintain(const player_proxy& player);

    virtual std::string get_name() const;
    virtual void start();

    virtual void do_start_throw();
    virtual void do_stop_throw();
    virtual void do_look_upward();
    virtual void do_continue_look_upward();
    virtual void do_crouch();
    virtual void do_continue_crouch();
  }; // class state_maintain
} // namespace ptb

#endif // __PTB_STATE_MAINTAIN_HPP__
